==> apache-johnzon-1.2.21-src.tar.gz: apache-johnzon-1.2.21-src/johnzon-jsonb/src/main/java/org/apache/johnzon/jsonb/serializer/JohnzonSerializationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.johnzon.jsonb.serializer;

import org.apache.johnzon.mapper.MappingGenerator;

import javax.json.bind.serializer.SerializationContext;
import javax.json.stream.JsonGenerator;

// TODO: fix it
public class JohnzonSerializationContext implements SerializationContext {
    private final MappingGenerator runtime;

    public JohnzonSerializationContext(final MappingGenerator runtime) {
        this.runtime = runtime;
    }

    @Override
    public <T> void serialize(final String key, final T object, final JsonGenerator generator) {
        runtime.writeObject(key, object, generator);
    }

    @Override
    public <T> void serialize(final T object, final JsonGenerator generator) {
        runtime.writeObject(object, generator);
    }
}

==> apache-johnzon-2.0.0-src.tar.gz: apache-johnzon-2.0.0-src/johnzon-jsonb/src/main/java/org/apache/johnzon/jsonb/serializer/JohnzonSerializationContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.johnzon.jsonb.serializer;

import org.apache.johnzon.mapper.MappingGenerator;

import jakarta.json.bind.serializer.SerializationContext;
import jakarta.json.stream.JsonGenerator;

// TODO: fix it
public class JohnzonSerializationContext implements SerializationContext {
    private final MappingGenerator runtime;

    public JohnzonSerializationContext(final MappingGenerator runtime) {
        this.runtime = runtime;
    }

    @Override
    public <T> void serialize(final String key, final T object, final JsonGenerator generator) {
        runtime.writeObject(key, object, generator);
    }

    @Override
    public <T> void serialize(final T object, final JsonGenerator generator) {
        runtime.writeObject(object, generator);
    }
}
